==> fillets-ng-data-0.7.1.tar.gz: fillets-ng-data-0.7.1/script/engine/dialogs_cs.lua <==

dialogId("mot-m-info", "font_small", "I think we can gain some information about the interstellar propulsion here.")
dialogStr("Myslím, že bychom tu mohli získat nějaké informace o mezihvězdném pohonu.")


dialogId("mot-v-konvencni", "font_big", "This looks more like conventional propulsion for the landing craft.")
dialogStr("Tohle vypadá spíš na konvenční pohon pro výsadková vozidla.")


dialogId("mot-m-tak", "font_small", "So. We found the drive. We have achieved one of the objectives of our mission.")
dialogStr("Tak. Našli jsme motor. Mohli bychom prohlásit jeden z našich úkolů za splněný.")


dialogId("mot-v-zavery", "font_big", "Don`t be so hasty. We haven`t searched the whole wreck yet.")
dialogStr("Nedělej ukvapené závěry. Ještě jsme neprohlédli celý vrak.")


dialogId("mot-m-akce0", "font_small", "I am sorry that none of these technical marvels around us work.")
dialogStr("To je škoda, že všechna ta technika, kterou tu vidíme, už nefunguje.")


dialogId("mot-m-akce1", "font_small", "I`d like to see some of these extraterrestrial gizmos in action.")
dialogStr("Já bych tak chtěla vidět trochu té mimozemské techniky v akci.")


dialogId("mot-m-akce2", "font_small", "I wonder if this motor could work under water.")
dialogStr("To by mě zajímalo, jestli by tenhle motor fungoval i pod vodou.")


dialogId("mot-v-funkce0", "font_big", "Maybe it`s better for us if it doesn`t work.")
dialogStr("Možná je pro nás lepší, že už tu nic nepracuje.")


dialogId("mot-v-funkce1", "font_big", "I am rather glad we cannot turn anything on here.")
dialogStr("Já jsem spíš rád, že tu nemůžeme nic zapnout.")


dialogId("mot-v-funkce2", "font_big", "We should be happy that we could not switch anything on yet.")
dialogStr("Naše štěstí je, že tu nemůžeme nic zapnout.")


dialogId("mot-v-klic", "font_big", "Careful with that wrench.")
dialogStr("Opatrně s tím klíčem.")


dialogId("mot-m-ublizit", "font_small", "I can`t harm anything here.")
dialogStr("Tady přece nemůžu ničemu ublížit.")


dialogId("mot-m-zvuky0", "font_small", "What have you done? Turn off that roar!")
dialogStr("Co jsi to udělal? Vypni ten randál!")


dialogId("mot-m-zvuky1", "font_small", "This is terrible! Turn it off before it`s too late!")
dialogStr("To jsou strašné zvuky! Vypni to dřív, než bude pozdě.")


dialogId("mot-v-nemuzu0", "font_big", "I can`t! I can`t take it out!")
dialogStr("Nemůžu! Jak to mám vytáhnout?!")


dialogId("mot-v-nemuzu1", "font_big", "I don`t know how! I can`t take it out!")
dialogStr("Nevím jak! Nedá se to vyndat!")


dialogId("mot-m-mayday", "font_small", "Mayday! Mayday!")
dialogStr("Mayday! Mayday!")


dialogId("mot-v-konecne0", "font_big", "Finally.")
dialogStr("Konečně.")


dialogId("mot-v-konecne1", "font_big", "What a relief.")
dialogStr("To se mi ulevilo")


dialogId("mot-v-zvuky0", "font_big", "What are you doing? Where are we going?")
dialogStr("Co to děláš? Kam to jedeme?")


dialogId("mot-v-zvuky1", "font_big", "What have you activated? Where is it taking us?")
dialogStr("Co jsi to aktivovala? Kam nás to veze?")


dialogId("mot-m-nemuzu0", "font_small", "How can I turn it off?!")
dialogStr("Kde se to vypíná?!")


dialogId("mot-m-nemuzu1", "font_small", "I can`t turn it off!")
dialogStr("Nedá se to vypnout!")


dialogId("mot-m-konecne0", "font_small", "Thanks.")
dialogStr("Díky.")


dialogId("mot-m-konecne1", "font_small", "Finally.")
dialogStr("Konečně.")


dialogId("mot-v-znovu0", "font_big", "I am only afraid we`ll have to turn it on again.")
dialogStr("Bojím se, že to budeme muset zapnout znovu.")

==> fillets-ng-data_1.0.1.orig.tar.gz: fillets-ng-data-1.0.1/script/engine/dialogs_cs.lua <==

dialogId("mot-m-info", "font_small", "I think we can gain some information about the interstellar propulsion here.")
dialogStr("Myslím, že bychom tu mohli získat nějaké informace o mezihvězdném pohonu.")


dialogId("mot-v-konvencni", "font_big", "This looks more like conventional propulsion for the landing craft.")
dialogStr("Tohle vypadá spíš na konvenční pohon pro výsadková vozidla.")


dialogId("mot-m-tak", "font_small", "So. We found the drive. We have achieved one of the objectives of our mission.")
dialogStr("Tak. Našli jsme motor. Mohli bychom prohlásit jeden z našich úkolů za splněný.")


dialogId("mot-v-zavery", "font_big", "Don’t be so hasty. We haven’t searched the whole wreck yet.")
dialogStr("Nedělej ukvapené závěry. Ještě jsme neprohlédli celý vrak.")


dialogId("mot-m-akce0", "font_small", "I am sorry that none of these technical marvels around us work.")
dialogStr("To je škoda, že všechna ta technika, kterou tu vidíme, už nefunguje.")


dialogId("mot-m-akce1", "font_small", "I’d like to see some of these extraterrestrial gizmos in action.")
dialogStr("Já bych tak chtěla vidět trochu té mimozemské techniky v akci.")


dialogId("mot-m-akce2", "font_small", "I wonder if this motor could work under water.")
dialogStr("To by mě zajímalo, jestli by tenhle motor fungoval i pod vodou.")


dialogId("mot-v-funkce0", "font_big", "Maybe it’s better for us if it doesn’t work.")
dialogStr("Možná je pro nás lepší, že už tu nic nepracuje.")


dialogId("mot-v-funkce1", "font_big", "I am rather glad we cannot turn anything on here.")
dialogStr("Já jsem spíš rád, že tu nemůžeme nic zapnout.")


dialogId("mot-v-funkce2", "font_big", "We should be happy that we could not switch anything on yet.")
dialogStr("Naše štěstí je, že tu nemůžeme nic zapnout.")


dialogId("mot-v-klic", "font_big", "Careful with that wrench.")
dialogStr("Opatrně s tím klíčem.")


dialogId("mot-m-ublizit", "font_small", "I can’t harm anything here.")
dialogStr("Tady přece nemůžu ničemu ublížit.")


dialogId("mot-m-zvuky0", "font_small", "What have you done? Turn off that roar!")
dialogStr("Co jsi to udělal? Vypni ten randál!")


dialogId("mot-m-zvuky1", "font_small", "This is terrible! Turn it off before it’s too late!")
dialogStr("To jsou strašné zvuky! Vypni to dřív, než bude pozdě.")


dialogId("mot-v-nemuzu0", "font_big", "I can’t! I can’t take it out!")
dialogStr("Nemůžu! Jak to mám vytáhnout?!")


dialogId("mot-v-nemuzu1", "font_big", "I don’t know how! I can’t take it out!")
dialogStr("Nevím jak! Nedá se to vyndat!")


dialogId("mot-m-mayday", "font_small", "Mayday! Mayday!")
dialogStr("Mayday! Mayday!")


dialogId("mot-v-konecne0", "font_big", "Finally.")
dialogStr("Konečně.")


dialogId("mot-v-konecne1", "font_big", "What a relief.")
dialogStr("To se mi ulevilo")


dialogId("mot-v-zvuky0", "font_big", "What are you doing? Where are we going?")
dialogStr("Co to děláš? Kam to jedeme?")


dialogId("mot-v-zvuky1", "font_big", "What have you activated? Where is it taking us?")
dialogStr("Co jsi to aktivovala? Kam nás to veze?")


dialogId("mot-m-nemuzu0", "font_small", "How can I turn it off?!")
dialogStr("Kde se to vypíná?!")


dialogId("mot-m-nemuzu1", "font_small", "I can’t turn it off!")
dialogStr("Nedá se to vypnout!")


dialogId("mot-m-konecne0", "font_small", "Thanks.")
dialogStr("Díky.")


dialogId("mot-m-konecne1", "font_small", "Finally.")
dialogStr("Konečně.")


dialogId("mot-v-znovu0", "font_big", "I am only afraid we’ll have to turn it on again.")
dialogStr("Bojím se, že to budeme muset zapnout znovu.")
